Get mapping of input variables names and names used in the model
Source:R/plot_diagnotics.R
get_variables_names.RdGet mapping of input variables names and names used in the model

R/plot_diagnotics.R
get_variables_names.RdGet mapping of input variables names and names used in the model