Skip to contents

Plot the sampling of parameters highlighting the iterations where divergent transitions occurred

Usage

plot_divergent_transitions(
  x,
  days_from = NULL,
  parameters = NULL,
  nuts_params = "divergent__"
)

Arguments

x

TOSCA object

days_from

date from which to compute the distance from for times

parameters

parameters one desires to retrieve the posterior for

nuts_params

annotations from bayes plot ("lp__", "energy__", "stepsize__","n_leapfrog__", "accept_stat__", "treedepth__")

Value

plot