Skip to contents

Plot the posterior predictive distribution and compares it to the real number of mutations

Usage

plot_ppc_single_mut(x, mut1_real, mut2_real, rep_name1, rep_name2)

Arguments

x

TOSCA object

mut1_real

real value of the first mutation type of interest

mut2_real

real value of the second mutation type of interest

rep_name1

name of the posterior predictive variable corresponding to the first mutation type of interest, as reported in the model

rep_name2

name of the posterior predictive variable corresponding to the second mutation type of interest, as reported in the model

Value

plot