Skip to contents

Plot clinical timeline + posterior times with histogram

Usage

plot_timing(x, days_from = NULL, event_name = NULL)

Arguments

x

TOSCA obj

days_from

optional reference date (string, "YYYY-mm-dd"); if given, the x-axis is expressed as days from this date instead of calendar dates.

event_name

label for the reference date marker, used only when days_from is provided.

Value

posterior distributions of the inferred timing variables on the clinical timeline

Examples

data("exampleFit")
plot_timing(exampleFit)
#> Warning: Dropping 'draws_df' class as required metadata was removed.
#> No id variables; using all as measure variables