Skip to contents

Plot clinical timeline + posterior times with histogram in days from a chosen date

Usage

plot_timing_days(x, days_from = NULL, event_name = "Custom zero")

Arguments

x

TOSCA obj

days_from

date from which to compute the distance from for times. If NULL, defaults to the earliest sample date.

event_name

label for the reference date marker

Value

posterior distributions of the inferred timing variables on the clinical timeline (alternative visualisation)

Examples

data("exampleFit")
plot_timing_days(exampleFit)
#> Warning: plot_timing_days() is deprecated; use plot_timing(x, days_from = ..., event_name = ...) instead.
#> Warning: Dropping 'draws_df' class as required metadata was removed.
#> No id variables; using all as measure variables
#> Don't know how to automatically pick scale for object of type <difftime>.
#> Defaulting to continuous.