Plot the sampling of parameters highlighting the iterations where divergent transitions occurred
plot_divergent_transitions.RdPlot the sampling of parameters highlighting the iterations where divergent transitions occurred
Usage
plot_divergent_transitions(
x,
days_from = NULL,
parameters = NULL,
nuts_params = "divergent__"
)