Plot the posterior predictive distribution and compares it to the real number of mutations
plot_ppc_single_mut.RdPlot the posterior predictive distribution and compares it to the real number of mutations
Arguments
- x
TOSCA object
- mut1_real
real value of the first mutation type of interest
- mut2_real
real value of the second mutation type of interest
- rep_name1
name of the posterior predictive variable corresponding to the first mutation type of interest, as reported in the model
- rep_name2
name of the posterior predictive variable corresponding to the second mutation type of interest, as reported in the model