Plot clinical timeline + posterior times with histogram in days from a chosen date
Source:R/plot_timing.R
plot_timing_days.RdPlot clinical timeline + posterior times with histogram in days from a chosen date
Value
posterior distributions of the inferred timing variables on the clinical timeline (alternative visualisation)
Examples
data("exampleFit")
plot_timing_days(exampleFit)
#> Warning: plot_timing_days() is deprecated; use plot_timing(x, days_from = ..., event_name = ...) instead.
#> Warning: Dropping 'draws_df' class as required metadata was removed.
#> No id variables; using all as measure variables
#> Don't know how to automatically pick scale for object of type <difftime>.
#> Defaulting to continuous.